@@ -30,7 +30,7 @@ class Risk(NetBoxModel):
         return self.name
 
     def get_absolute_url(self):
-        return reverse('plugins:risks:risk', args=[self.pk])
+        return reverse('plugins:users_and_computers:risk', args=[self.pk])
 
 
 class RiskRelation(NetBoxModel):
@@ -52,7 +52,7 @@ class RiskRelation(NetBoxModel):
         return self.name
 
     def get_absolute_url(self):
-        return reverse('plugins:risks:riskrelation', args=[self.pk])
+        return reverse('plugins:users_and_computers:riskrelation', args=[self.pk])
 
 
 class RiskAssignment(WebhooksMixin, ChangeLoggedModel):
@@ -87,7 +87,7 @@ class RiskAssignment(WebhooksMixin, ChangeLoggedModel):
         return str(self.risk)
 
     def get_absolute_url(self):
-        return reverse('plugins:risks:risk', args=[self.risk.pk])
+        return reverse('plugins:users_and_computers:risk', args=[self.risk.pk])
 
 
 @receiver(post_delete, sender=VirtualMachine, dispatch_uid='del_risk_assignment')
