@@ -4,7 +4,7 @@ from utilities.choices import ButtonColorChoices
 
 risk_buttons = [
     PluginMenuButton(
-        link='plugins:risks:risk_add',
+        link='plugins:users_and_computers:risk_add',
         title='Add',
         icon_class='mdi mdi-plus-thick',
         color=ButtonColorChoices.GREEN
@@ -12,7 +12,7 @@ risk_buttons = [
 ]
 risk_rel_buttons = [
     PluginMenuButton(
-        link='plugins:risks:riskrelation_add',
+        link='plugins:users_and_computers:riskrelation_add',
         title='Add',
         icon_class='mdi mdi-plus-thick',
         color=ButtonColorChoices.GREEN
@@ -21,12 +21,12 @@ risk_rel_buttons = [
 
 menu_items = (
     PluginMenuItem(
-        link='plugins:risks:risk_list',
+        link='plugins:users_and_computers:risk_list',
         link_text='Risks',
         buttons=risk_buttons
     ),
     PluginMenuItem(
-        link='plugins:risks:riskrelation_list',
+        link='plugins:users_and_computers:riskrelation_list',
         link_text='Risk Relations',
         buttons=risk_rel_buttons
     ),
